{{! Takker Automatic docstring}}

:说明: `{{name}}`
> {{summaryPlaceholder}} {{extendedSummaryPlaceholder}}
{{#argsExist}}

:参数:
{{#args}}
  * `{{var}}: {{typePlaceholder}}`: {{descriptionPlaceholder}}
{{/args}}
{{/argsExist}}
{{#kwargsExist}}

:可选参数:
{{#kwargs}}
  * `{{var}}: {{typePlaceholder}} = {{default}}`: {{descriptionPlaceholder}}
{{/kwargs}}
{{/kwargsExist}}
{{#exceptionsExist}}

:Exceptions:
{{#exceptions}}
  * `{{var}}`: {{descriptionPlaceholder}}
{{/exceptions}}
{{/exceptionsExist}}
{{#yieldsExist}}

:生成:
{{#yields}}
  * `{{typePlaceholder}}`: {{descriptionPlaceholder}}
{{/yields}}
{{/yieldsExist}}
{{#returnsExist}}

:返回:
{{#returns}}
  - `{{typePlaceholder}}`: {{descriptionPlaceholder}}
{{/returns}}
{{/returnsExist}}